@@ -3,6 +3,7 @@ from gcgen.emitter import Emitter
 from gcgen.decorators import snippet, generator
 from gcgen.api.snippets_helpers import get_snippet, SnippetFn
 from gcgen.api.write_file import write_file
+from gcgen.api.types import Json
 
 
 __all__ = [
@@ -13,4 +14,5 @@ __all__ = [
     "generator",
     "get_snippet",
     "write_file",
+    "Json"
 ]
