@@ -15,7 +15,7 @@ import os
 from io import TextIOWrapper
 from gcgen.scope import Scope
 from gcgen import decorators
-from gcgen.snippetparser import ParserBase
+from gcgen.snippetparser import ParserBase, Json
 from gcgen.emitter import Emitter
 from gcgen.log import get_logger, LogLevel
 from gcgen.api.snippets_helpers import SnippetFn
@@ -106,7 +106,7 @@ class Parser(ParserBase):
         self._scope = scope
 
     def on_snippet(
-        self, snippet_name: str, snippet_prefix: str, src_path: Path, fh: TextIOWrapper
+        self, snippet_prefix: str, snippet_name: str, snippet_arg: Json, src_path: Path, fh: TextIOWrapper
     ):
         logger.debug(f"on_snippet {snippet_name!r} called")
         snippet_fn: Union[SnippetFn, None] = self._snippets_scope.get(
@@ -124,7 +124,7 @@ class Parser(ParserBase):
         scope["$file"] = fpath
         scope["$snippets"] = self._snippets_scope.derive()
         try:
-            snippet_fn(emitter, scope)
+            snippet_fn(emitter, scope, snippet_arg)
         except Exception as e:
             logger.error(
                 f"error executing snippet {snippet_name!r} in {fpath!s}", exc_info=True
@@ -176,7 +176,7 @@ class CompileScopeExtendError(CompileError):
         print("")
         print("Encountered an unhandled exception while executing the user-defined")
         print(
-            "scope extend hook in the `gcgen.py` configuration file (see path below)."
+            "scope extend hook in the `gcgen_conf.py` configuration file (see path below)."
         )
         print("Please see the exception traceback information above for details.")
         print("")
@@ -196,7 +196,9 @@ class CompileParseFilesError(CompileError):
         print("Exception while executing `gcgen_parse_files` hook")
         print("")
         print("Encountered an unhandled exception while executing the user-defined")
-        print("parse files hook in the `gcgen.py` configuration file (see path below).")
+        print(
+            "parse files hook in the `gcgen_conf.py` configuration file (see path below)."
+        )
         print("Please see the exception traceback information above for details.")
         print("")
         print("Details:")
@@ -214,13 +216,13 @@ class CompileExcludeFilesError(CompileError):
         print("")
         print("Encountered an unhandled exception while executing the user-defined")
         print(
-            "exclude dirs hook in the `gcgen.py` configuration file (see path below)."
+            "exclude dirs hook in the `gcgen_conf.py` configuration file (see path below)."
         )
         print("Please see the exception traceback information above for details.")
         print("")
         print("Details:")
         print(f"  config: {self.conf_path}")
-        print(f"  hook: cgen_exclude_dirs")
+        print(f"  hook: gcgen_exclude_dirs")
 
 
 class CompileGeneratorFunctionError(CompileError):
@@ -236,7 +238,7 @@ class CompileGeneratorFunctionError(CompileError):
         print("")
         print("Encountered an unhandled exception while executing the user-defined")
         print(
-            f"generator function {self.generator_fn_name!r} defined in the `gcgen.py` configuration"
+            f"generator function {self.generator_fn_name!r} defined in the `gcgen_conf.py` configuration"
         )
         print("file mentioned below.")
         print("Please see the exception traceback information above for details.")
@@ -265,7 +267,7 @@ class ParseFilesInvalidValue(ParseFilesError):
         print("containined in other directories than the currently processed one.")
         print("")
         print(
-            "TIP: If you want these files to reside elsewhere, add a `gcgen.py` in that"
+            "TIP: If you want these files to reside elsewhere, add a `gcgen_conf.py` in that"
         )
         print(
             "directory, remove the entries from this file and re-run the compilation."
@@ -278,7 +280,7 @@ class ParseFilesInvalidValue(ParseFilesError):
         else:
             # only print this way if type is different from expected
             print(f"  entry: {self.fpath!r}")
-        print(f"  hook: cgen_parse_files")
+        print(f"  hook: gcgen_parse_files")
 
 
 class ParseFileNotFoundError(ParseFilesError):
@@ -297,7 +299,7 @@ class ParseFileNotFoundError(ParseFilesError):
         print("Details:")
         print(f"  conf: {self.conf_path}")
         print(f"  entry: {self.fpath}")
-        print(f"  hook: cgen_parse_files")
+        print(f"  hook: gcgen_parse_files")
 
 
 class ParseFileNotFileError(ParseFilesError):
@@ -315,7 +317,7 @@ class ParseFileNotFileError(ParseFilesError):
         print("Details:")
         print(f"  conf: {self.conf_path}")
         print(f"  entry: {self.fpath}")
-        print(f"  hook: cgen_parse_files")
+        print(f"  hook: gcgen_parse_files")
 
 
 class IndentByValueError(GcgenError):
@@ -326,7 +328,7 @@ class IndentByValueError(GcgenError):
     def printerr(self) -> None:
         print("`gcen_indent_by` is not a dictionary!")
         print("")
-        print("The indent by variable in `gcgen.py` must be a dictionary value")
+        print("The indent by variable in `gcgen_conf.py` must be a dictionary value")
         print(
             "whose entries are strings matching filename suffixes (i.e. 'py', 'go', ...)"
         )
@@ -375,7 +377,7 @@ def get_mod_snippet_fns(mod: ModuleType) -> Dict[str, Callable]:
     return {name: fn for name, fn in mod.__dict__.items() if decorators.is_snippet(fn)}
 
 
-def compile(root: Path, tag_start: str = "[[start", tag_end: str = "end]]"):
+def compile(root: Path, tag_start: str = "<<?", tag_end: str = "?>>"):
     # in case `root` is a relative path like '.', resolve to absolute path
     # for later use, where cwd changes.
     root = root.resolve()
@@ -384,7 +386,7 @@ def compile(root: Path, tag_start: str = "[[start", tag_end: str = "end]]"):
         path: Path, parent_scope: Scope, snippets_scope: Scope, indent_by: Scope
     ):
         gcgen_mod = None
-        gcgen_conf_path = path / "gcgen.py"
+        gcgen_conf_path = path / "gcgen_conf.py"
         if gcgen_conf_path.exists():
             gcgen_mod = import_from_path(root, gcgen_conf_path)
         scope = parent_scope.derive()
@@ -433,7 +435,7 @@ def compile(root: Path, tag_start: str = "[[start", tag_end: str = "end]]"):
         if gcgen_mod is None:
             return
 
-        # operate from within the path containing the gcgen.py we are currently processing
+        # operate from within the path containing the gcgen_conf.py we are currently processing
         os.chdir(path)
         # parse snippets in any files explicitly listed as having them
         if hasattr(gcgen_mod, "gcgen_parse_files"):
@@ -451,7 +453,7 @@ def compile(root: Path, tag_start: str = "[[start", tag_end: str = "end]]"):
                 file = Path(file)
                 if str(file) != file.name:
                     logger.error(
-                        f"{file!s} - entries in `cgen_parse_files` must be plain filenames, not paths!",
+                        f"{file!s} - entries in `gcgen_parse_files` must be plain filenames, not paths!",
                     )
                     raise ParseFilesInvalidValue(file, gcgen_conf_path)
 
